function [cs, dq, b] = CSD(d, wl)

%CSD representation of a number d between -4/3 to 4/3
%
%INPUTS:
%   d: a number between -4/3 to 4/3
%   wl: wordlength
%
%OUTPUTS:
%   cs: a row vector containing the CSD digits -1,0 or 1
%   dq: d rounded to wl bits
%   b: 2's complement representation of dq
%
%KEY CAREABOUT
%   1. Impelemented the CSD conversion algorithm in Parhi's book--'VLSI digital signal processing'
%
%SEE ALSO quantize.m
%
%EXAMPLE:
%d = 0.235; wl=15;
%[cs, dq, b] = CSD(d, wl);

if abs(d)>4/3
    display('Input to the CSD function is our of range');
end
d_orig = d;
if d >=1
    d=d-1;
elseif d<=-1
    d=d+1;
end
% q=quantizer([wl wl-1], 'fixed','round');
% f = num2bin(q,d);
% b = zeros(1,length(f));
% for i =1:length(f)
%     b(i) = str2num(f(i));
% end
[dq, b] = quantize(d, wl, 1);
if d_orig >=1
    dq = dq+1;
elseif d_orig<=-1
    dq=dq-1;
end
a = [b(1) b 0];
aa = zeros(1,length(b));
gama = zeros(1,length(b)+1);
theta = zeros(1,length(b));
for i = length(b):-1:1
    theta(i) =  xor(a(i+1), a(i+2));
    gama(i) = not(gama(i+1))*theta(i);
    aa(i) = (1-2*a(i))*gama(i);
end
cs = aa;
if d_orig>=1
    cs(1)=1;
else 
    if d<=-1
        cs(1) = -1;
    end
end

% cs = [];
% for i =1:length(aa)
%     if aa(i) == 0
%         cs = [cs, '0'];
%     elseif aa(i) == 1
%         cs = [cs, '1'];
%     elseif aa(i) == -1
%         cs = [cs, '-'];
%     end
% end
% 
% if d_orig >=1
%     cs(1) = '1';
% elseif d_orig <= -1
%     cs(1) = '-';
% end