function [y, bitvec, overflow] = quantize(x, wl, type)

%Quantize fractional number x and generate its 2's complement representation
%
%INPUTS:
%   x: fractional number
%   wl: wordlength
%   type: type = 1 => rounding, type = 0 => truncation 
%OUTPUTS:
%   y: quantized value
%   bitvec: 2's complement represenation, first bit beign the MSB
%  
%EXAMPLE
% x=0.234; wl=13; type=1
% [y, bitvec, overflow] = qauntize(x, format, type);

% wlint = 0;
% wlfrac = wl-1;
bitvec = zeros(1,wl);

xx = abs(x)*2^(wl-1);

if type
    xx = round(xx);
else
    xx = fix(xx);
end

if xx > 2^(wl-1)-1
    overflow=1; 
    sprintf('Warning: overflow happened.');
    yy = 2^(wl-1)-1;
else
    yy = xx;
    overflow=0;
end

if x>=0
    y = yy/2^(wl-1);
    for i=1:wl-1
        a =  mod(yy,2);
        bitvec(wl-i+1) = a;
        yy = (yy - a)/2;
    end
    bitvec(1) =0;
else
    y = -yy/2^(wl-1);
    yy = 2^(wl-1)-yy;
    for i=1:wl-1
        a =  mod(yy,2);
        bitvec(wl-i+1) = a;
        yy = (yy - a)/2;
    end
    bitvec(1) =1;   
end
    
